@@ -1,8 +1,8 @@
 import json
 import uuid
+import base64
 import requests
 import webbrowser
-from requests.auth import HTTPDigestAuth
 
 class payUnit:
     """
